/***** interface.c ************************************************
 * Description: Routine for gathering arguments from the command
 *              line.
 * Author: Bernhard Haubold, haubold@evolbio.mpg.de
 * Date: Sun Jun 20 13:12:10 2004.
 *****************************************************************/
#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
#include "interface.h"
#include "eprintf.h"

Args *args;

Args *getArgs(int argc, char *argv[]){
  char c;
  char *optString = "hvaS:s:t:r:l:g:";

  args = (Args *)emalloc(sizeof(Args));
  args->s = DEFAULT_S;
  args->t = DEFAULT_T;
  args->r = DEFAULT_R;
  args->l = DEFAULT_L;
  args->S = "sbjct.fasta";
  args->q = "query.fasta";
  args->g = 0.5;
  args->a = 0;
  args->h = 0;
  args->v = 0;
  args->e = 0;

  c = getopt(argc, argv, optString);
  while(c != -1){
    switch(c){
    case 'S':                           /* file name for sbjct sequence */
      args->S = optarg;
      break;
    case 'q':                           /* file nema for query sequence */
      args->q = optarg;
      break;
    case 's':                           /* number of segregating sites */
      args->s = atoi(optarg);
      break;
    case 't':                           /* theta */
      args->t = atof(optarg);
      args->s = 0;
      break;
    case 'r':                           /* rho */
      args->r = atof(optarg);
      break;
    case 'g':                           /* GC-content */
      args->g = atof(optarg);
      break;
    case 'l':                           /* sequence length */
      args->l = atoi(optarg);
      break;
    case 'a':                           /* use macs */
      args->a = 1;
      break;
    case '?':                           /* fall-through is intentional */
    case 'h':                           /* print help */
      args->h = 1;
      break;
    case 'v':                           /* print version */
      args->v = 1;
      break;
    default:
      printf("# unknown argument: %c\n",c);
      args->e = 1;
      return args;
    }
    c = getopt(argc, argv, optString);
  }
  if(args->s > 0 && args->t > 0){
    printf("ERROR[generateQuerySbjct]: please specify either -s or -t, not both.\n");
    args->e = 1;
  }
  return args;
}


void printUsage(char *version){
  printf("Usage: %s [options]\n",progname());
  printf("Generate a query and a subject sequence\n");
  printf("Example: generateQuerySbjct -t 1000 -r 1000 -l 100000\n");
  printf("Dependencies: ms, macs, ms2dna\n");
  printf("Options:\n");
  printf("\t[-s <NUM> number of segregating sites (excludes -t); default: %d]\n",DEFAULT_S);
  printf("\t[-t <NUM> theta (excludes -s); default: %.2f]\n",DEFAULT_T);
  printf("\t[-r <NUM> rho; default: %.2f]\n",DEFAULT_R);
  printf("\t[-g <NUM> GC-content; default: %.2f]\n",0.5);
  printf("\t[-l <NUM> sequence length; default: %d]\n",DEFAULT_L);
  printf("\t[-S <FILE> name of file for sbjct sequence; default: sbjct.fasta]\n");
  printf("\t[-q <FILE> name of file for query sequence; default: query.fasta]\n");
  printf("\t[-a use macs; derfault: use ms]\n");
  printf("\t[-h print this help message and exit]\n");
  printf("\t[-v print program information and exit]\n");
  exit(0);
}

void printSplash(char *version){
  printf("%s %s\n",progname(),version);
  printf("Written by Bernhard Haubold.\n");
  printf("Distributed under the GNU General Public License.\n");
  printf("Please send bug reports to haubold@evolbio.mpg.de\n");
  exit(0);
}
